==> api_server_controller-0.1.9a8-py3-none-any.whl: asc/core/tools/storage/control.py <==
import qrcode
from os import path, makedirs
from sqlalchemy.exc import IntegrityError

from asc import message
from asc.core import log
from asc.core import env
from asc.core.ABC.Control import ControlTool
from asc.core.tools.storage import core
from asc.models.storage import StorageFile
from asc.exceptions.storage import StorageException


class ControlToolHandler(ControlTool):

    def __init__(self):
        super(ControlToolHandler, self).__init__()
        self.zone:str = env.get('storage__path_zone')
        self.fold:str = None
        self.path:str = None

        if not self.zone:
            raise StorageException(
                message.E_NOT_CONFIGURED_STORAGE_ZONE)

    def set_fold(self, fold:str):
        """
        Define pasta a ser utilizada dentro da zona. Cria quando não existente.
        :param fold: nome da pasta.
        :return:
        """
        self.fold = fold
        self.path = f'{self.zone}{fold}/'

        if not path.isdir(self.path):
            makedirs(self.path, 0o755)

    def save_file(self, file_path, file_name, id_ref:int) -> str:
        """

        :param file_path:
        :param file_name:
        :param id_ref:
        :return: caminho para o arquivo
        """

        file = StorageFile(
            file_fold=self.fold,
            file_path=file_path,
            file_name=file_name,
        )

        self.session.add(file)
        self.commit()

        return f'{file_path}/{file_name}'

    def save_qrcode(self, data:str, id_ref:int, name:str='qrcode.png'):
        """
        Salva string de qrcode em arquivo png.
        :param data:
        :param id_ref:
        :param name:
        :return:
        """
        img_byte = qrcode.make(data)
        img_path = core.get_link_path(id_ref)
        img_file = f'{self.path}{img_path}'

        if path.isdir(img_file):
            raise StorageException.StoragePathFileAlreadyExists()

        makedirs(img_file, 0o755)
        img_byte.save(f'{img_file}/{name}')

        return self.save_file(img_path, name, id_ref)

==> api_server_controller-0.2.2a5-py3-none-any.whl: asc/core/tools/storage/control.py <==
import qrcode
from os import path, makedirs
from typing import Tuple
from sqlalchemy.exc import IntegrityError

from asc import message
from asc.core import log
from asc.core import env
from asc.core.ABC.Control import ControlTool
from asc.core.tools.storage import core
from asc.models.storage import StorageFile
from asc.exceptions.storage import StorageException


class ControlToolHandler(ControlTool):

    def __init__(self):
        super(ControlToolHandler, self).__init__()
        self.zone:str = env.get('storage__path_zone')
        self.fold:str = None
        self.path:str = None

        if not self.zone:
            raise StorageException(
                message.E_NOT_CONFIGURED_STORAGE_ZONE)

    def set_fold(self, fold:str):
        """
        Define pasta a ser utilizada dentro da zona. Cria quando não existente.
        :param fold: nome da pasta.
        :return:
        """
        self.fold = fold
        self.path = f'{self.zone}{fold}/'

        if not path.isdir(self.path):
            makedirs(self.path, 0o755)

    def get_file_link(self, id_storage:int) -> str:
        """ Retorna link de arquivo. """
        file = self.session.query(StorageFile) \
            .where(StorageFile.id_storage==id_storage)\
            .first()

        if not file:
            return False

        return f'{file.file_fold}/{file.file_path}/{file.file_name}'

    def save_file(self, file_path, file_name, id_ref:int) \
            -> Tuple[int, str]:
        """
        Salva arquivo na base de dados.
        :param file_path:
        :param file_name:
        :param id_ref:
        :return: id_storage e caminho para o arquivo
        """

        file = StorageFile(
            file_fold=self.fold,
            file_path=file_path,
            file_name=file_name,
        )

        self.session.add(file)
        self.commit()

        return (file.id_storage, f'{file_path}/{file_name}')

    def save_qrcode(self, data:str, id_ref:int, name:str='qrcode.png'):
        """
        Salva string de qrcode em arquivo png.
        :param data:
        :param id_ref:
        :param name:
        :return:
        """
        img_byte = qrcode.make(data)
        img_path = core.get_link_path(id_ref)
        img_file = f'{self.path}{img_path}'

        if path.isdir(img_file):
            raise StorageException.StoragePathFileAlreadyExists()

        makedirs(img_file, 0o755)
        img_byte.save(f'{img_file}/{name}')

        return self.save_file(img_path, name, id_ref)
